Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(869)

Unified Diff: base/i18n/icu_util.cc

Issue 9187053: Transition to base/mac/bundle_locations.h step 1 (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fix review comments. Created 8 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | base/mac/foundation_util.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: base/i18n/icu_util.cc
diff --git a/base/i18n/icu_util.cc b/base/i18n/icu_util.cc
index e5bbe17a9af5ad39589d52d5b4cabb8b4126fa36..193539d7ba4793b7e62c06e93a9bacb37c02aa65 100644
--- a/base/i18n/icu_util.cc
+++ b/base/i18n/icu_util.cc
@@ -109,9 +109,9 @@ bool Initialize() {
// be released.
static file_util::MemoryMappedFile mapped_file;
if (!mapped_file.IsValid()) {
// Assume it is in the MainBundle's Resources directory.
FilePath data_path =
- base::mac::PathForMainAppBundleResource(CFSTR(ICU_UTIL_DATA_FILE_NAME));
+ base::mac::PathForFrameworkBundleResource(CFSTR(ICU_UTIL_DATA_FILE_NAME));
if (data_path.empty()) {
DLOG(ERROR) << ICU_UTIL_DATA_FILE_NAME << " not found in bundle";
return false;
@@ -109,9 +109,9 @@ bool Initialize() {
static file_util::MemoryMappedFile mapped_file;
if (!mapped_file.IsValid()) {
- // Assume it is in the MainBundle's Resources directory.
+ // Assume it is in the framework bundle's Resources directory.
FilePath data_path =
« no previous file with comments | « no previous file | base/mac/foundation_util.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698